// COPYRIGHT NOTICE
// ----------------------------------------------------------------------------
// (This is the open source ISC license, see
// http://en.wikipedia.org/wiki/ISC_license
// for more info)
//
// Copyright © 2005-2023  Andreas M. Rammelt <rammi@caff.de>
//
// Permission to use, copy, modify, and/or distribute this software for any
// purpose with or without fee is hereby granted, provided that the above
// copyright notice and this permission notice appear in all copies.
//
// THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
// WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
// MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
// ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
// WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
// ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
// OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
//=============================================================================
// Latest version on https://caff.de/projects/decaff-commons/
//=============================================================================
package de.caff.util.args;

import de.caff.annotation.NotNull;
import de.caff.annotation.Nullable;

/**
 * Single required argument.
 * @author <a href="mailto:rammi@caff.de">Rammi</a>
 * @since January 27, 2019
 */
public class SingleArgument
        extends AbstractBasicArgument
{
  private final boolean optional;

  @Nullable
  private String value;

  public SingleArgument(@NotNull String name, @NotNull String description)
  {
    this(name, description, false);
  }

  public SingleArgument(@NotNull String name, @NotNull String description, boolean optional)
  {
    super(name, description);
    this.optional = optional;
  }

  @Override
  public boolean consumeArgument(@NotNull String arg)
  {
    assert value == null;
    value = arg;
    return false;
  }

  @Override
  public int getMinimalCount()
  {
    return optional ? 0 : 1;
  }

  @Override
  public int getMaximalCount()
  {
    return 1;
  }

  @Override
  public boolean isOptional()
  {
    return optional;
  }

  /**
   * Get the value.
   * @return value of this argument
   */
  @Nullable
  public String getValue()
  {
    return value;
  }
}
