//=============================================================================
// COPYRIGHT NOTICE
// ----------------------------------------------------------------------------
// (This is the open source ISC license, see
// http://en.wikipedia.org/wiki/ISC_license
// for more info)
//
// Copyright © 2014-2023  Andreas M. Rammelt <rammi@caff.de>
//
// Permission to use, copy, modify, and/or distribute this software for any
// purpose with or without fee is hereby granted, provided that the above
// copyright notice and this permission notice appear in all copies.
//
// THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
// WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
// MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
// ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
// WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
// ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
// OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
//=============================================================================
// Latest version on https://caff.de/projects/decaff-commons/
//=============================================================================
package de.caff.util.settings;

import de.caff.annotation.NotNull;

/**
 * Two-dimensional alignment as a combination of
 * vertical and horizontal alignment.
 *
 * @author <a href="mailto:rammi@caff.de">Rammi</a>
 */
public enum Alignment2D
{
  SouthWest(VerticalAlignment.South, HorizontalAlignment.West),
  South(VerticalAlignment.South, HorizontalAlignment.Center),
  SouthEast(VerticalAlignment.South, HorizontalAlignment.East),
  West(VerticalAlignment.Center, HorizontalAlignment.West),
  Center(VerticalAlignment.Center, HorizontalAlignment.Center),
  East(VerticalAlignment.Center, HorizontalAlignment.East),
  NorthWest(VerticalAlignment.North, HorizontalAlignment.West),
  North(VerticalAlignment.North, HorizontalAlignment.Center),
  NorthEast(VerticalAlignment.North, HorizontalAlignment.East);

  @NotNull
  private final VerticalAlignment verticalAlignment;
  @NotNull
  private final HorizontalAlignment horizontalAlignment;

  /**
   * Constructor.
   * @param verticalAlignment   vertical alignment
   * @param horizontalAlignment horizontal alignment
   */
  Alignment2D(@NotNull VerticalAlignment verticalAlignment,
              @NotNull HorizontalAlignment horizontalAlignment)
  {
    this.verticalAlignment = verticalAlignment;
    this.horizontalAlignment = horizontalAlignment;
  }

  /**
   * Get the underlying vertical alignment.
   * @return vertical alignment
   */
  @NotNull
  public VerticalAlignment getVerticalAlignment()
  {
    return verticalAlignment;
  }

  /**
   * Get the underlying horizontal alignment.
   * @return horizontal alignment
   */
  @NotNull
  public HorizontalAlignment getHorizontalAlignment()
  {
    return horizontalAlignment;
  }
}
