// ============================================================================
// COPYRIGHT NOTICE
// ----------------------------------------------------------------------------
// (This is the open source ISC license, see
// http://en.wikipedia.org/wiki/ISC_license
// for more info)
//
// Copyright © 2016-2023  Andreas M. Rammelt <rammi@caff.de>
//
// Permission to use, copy, modify, and/or distribute this software for any
// purpose with or without fee is hereby granted, provided that the above
// copyright notice and this permission notice appear in all copies.
//
// THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
// WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
// MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
// ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
// WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
// ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
// OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
//=============================================================================
// Latest version on https://caff.de/projects/decaff-commons/
//=============================================================================
package de.caff.util.settings;

import de.caff.annotation.NotNull;

/**
 * Simple property holding a float value.
 * @author <a href="mailto:rammi@caff.de">Rammi</a>
 * @since November 28, 2016
 */
public class SimpleFloatProperty
        extends AbstractBasicChangeableItem
        implements Property<Float>
{
  private static final long serialVersionUID = -1782754644783033700L;

  private float value;

  /**
   * Constructor.
   * Construct a property with the given name or name prefix.
   *
   * @param basicName name or name prefix
   */
  public SimpleFloatProperty(@NotNull String basicName)
  {
    this(basicName, 0);
  }

  /**
   * Constructor.
   * Construct a property with the given name or name prefix.
   *
   * @param basicName name or name prefix
   * @param value     initial value
   */
  public SimpleFloatProperty(@NotNull String basicName,
                             float value)
  {
    super(basicName);
    this.value = value;
  }

  /**
   * Get the value of the property.
   *
   * @return property value
   */
  @Override
  @NotNull
  public Float getValue()
  {
    return value;
  }

  /**
   * Set the value.
   *
   * @param value new value (not {@code null})
   */
  @Override
  public void setValue(Float value)
  {
    if (value == null) {
      throw new IllegalArgumentException("value must not be null!");
    }
    setValue(value.floatValue());
  }

  /**
   * Set the value.
   *
   * @param value new value
   */
  public void setValue(float value)
  {
    if (value != this.value) {
      final float oldValue = this.value;
      this.value = value;
      fireValueChange(getPropertyName(), oldValue, value);
    }
  }
}
